
# Slot: interacting molecules category




URI: [biolink:interacting_molecules_category](https://w3id.org/biolink/vocab/interacting_molecules_category)

## Domain and Range

[PairwiseInteractionAssociation](PairwiseInteractionAssociation.md) ->  <sub>OPT</sub> [OntologyClass](OntologyClass.md)

## Parents


## Children


## Used by

 * [PairwiseInteractionAssociation](PairwiseInteractionAssociation.md)
